@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -36,16 +32,17 @@ class dhcp_scopeFixedAttributes(univention.admin.syntax.select):
 module = 'policies/dhcp_scope'
 operations = ['add', 'edit', 'remove', 'search']
 
-policy_oc = "univentionPolicyDhcpScope"
-policy_apply_to = ["dhcp/service", "dhcp/subnet", "dhcp/host", "dhcp/sharedsubnet", "dhcp/shared"]
-policy_position_dn_prefix = "cn=scope,cn=dhcp"
-policies_group = "dhcp"
+policy_oc = 'univentionPolicyDhcpScope'
+policy_apply_to = ['dhcp/service', 'dhcp/subnet', 'dhcp/host', 'dhcp/sharedsubnet', 'dhcp/shared']
+policy_position_dn_prefix = 'cn=scope,cn=dhcp'
+policies_group = 'dhcp'
 childs = False
 short_description = _('Policy: DHCP Allow/Deny')
 object_name = _('DHCP Allow/Deny policy')
 object_name_plural = _('DHCP Allow/Deny policies')
 policy_short_description = _('Allow/Deny')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -116,6 +113,7 @@ mapping.register('booting', 'univentionDhcpBooting', None, univention.admin.mapp
 mapping.register('duplicates', 'univentionDhcpDuplicates', None, univention.admin.mapping.ListToString)
 mapping.register('declines', 'univentionDhcpDeclines', None, univention.admin.mapping.ListToString)
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
