@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -102,6 +98,7 @@ class noProperty(base):
 
 
 class valueError(base):
+    """Value error base class"""
 
     def __init__(self, *args, **kwargs):
         self.property = kwargs.pop('property', None)
@@ -171,19 +168,19 @@ class adGroupTypeChangeGlobalToUniversal(base):
 
 
 class adGroupTypeChangeDomainLocalToUniversal(base):
-    message = _("The AD group type can not be changed from domain local to universal, because the group has another domain local group as member.")
+    message = _('The AD group type can not be changed from domain local to universal, because the group has another domain local group as member.')
 
 
 class adGroupTypeChangeUniversalToGlobal(base):
-    message = _("The AD group type can not be changed from universal to global, because the group has another universal group as member.")
+    message = _('The AD group type can not be changed from universal to global, because the group has another universal group as member.')
 
 
 class adGroupTypeChangeGlobalToDomainLocal(base):
-    message = _("The AD group type can not be changed from global to domain local.")
+    message = _('The AD group type can not be changed from global to domain local.')
 
 
 class adGroupTypeChangeDomainLocalToGlobal(base):
-    message = _("The AD group type can not be changed from domain local to global.")
+    message = _('The AD group type can not be changed from domain local to global.')
 
 
 class prohibitedUsername(base):
