@@ -1,18 +1,22 @@
 # SPDX-FileCopyrightText: 2018-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
+from __future__ import annotations
+
 import importlib
 import os.path
-from collections.abc import Iterable, Iterator  # noqa: F401
 from glob import glob
-from typing import cast
+from typing import TYPE_CHECKING, Any, cast
+
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator
 
 
 class Plugin(type):
     """Meta class for plugins."""
 
-    def __new__(mcs, name, bases, attrs):
-        # type: (Type[Plugin], str, Tuple[type, ...], Dict[str, Any]) -> Plugin
+    def __new__(mcs: type[Plugin], name: str, bases: tuple[type, ...], attrs: dict[str, Any]) -> Plugin:
         new_cls = cast(Plugin, super().__new__(mcs, name, bases, attrs))
         Plugins.add_plugin(new_cls)
         return new_cls
@@ -21,11 +25,10 @@ class Plugin(type):
 class Plugins:
     """Register `Plugin` subclasses and iterate over them."""
 
-    _plugins = []  # type: List[Plugin]
-    _imported = {}  # type: Dict[str, bool]
+    _plugins: list[Plugin] = []
+    _imported: dict[str, bool] = {}
 
-    def __init__(self, python_path):
-        # type: (str) -> None
+    def __init__(self, python_path: str) -> None:
         """
         :param str python_path: fully dotted Python path that the plugins will
                 be found below
@@ -34,8 +37,7 @@ class Plugins:
         self._imported.setdefault(python_path, False)
 
     @classmethod
-    def add_plugin(cls, plugin):
-        # type: (Plugin) -> None
+    def add_plugin(cls, plugin: Plugin) -> None:
         """
         Called by `Plugin` meta class to register a new `Plugin` subclass.
 
@@ -43,8 +45,7 @@ class Plugins:
         """
         cls._plugins.append(plugin)
 
-    def __iter__(self):
-        # type: () -> Iterator[Plugin]
+    def __iter__(self) -> Iterator[Plugin]:
         """
         Iterator for registered `Plugin` subclasses.
 
@@ -55,8 +56,7 @@ class Plugins:
             if plugin.__module__.startswith(self.python_path):
                 yield plugin
 
-    def load(self):
-        # type: () -> None
+    def load(self) -> None:
         """Load plugins."""
         if self._imported.get(self.python_path):
             return
